﻿SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
DROP FUNCTION IF EXISTS [dbo].[fnGetEvesOraszamLista]
GO

CREATE FUNCTION [dbo].[fnGetEvesOraszamLista] (
     @tantargyId int
    ,@osztalycsoportId int
    ,@tanarId int
    ,@datum datetime
    ,@intezmenyId int
    ,@tanevId int
)
RETURNS @return TABLE(Id int not null, EvesSorszam int)
AS
BEGIN
DECLARE @TanarSzamit bit = 0;
DECLARE @OsztalybontasEgybe bit = 0;
DECLARE @VanOsszerendeles bit = 0;
DECLARE @OsztalyTantargy TABLE(OsztalyCsoportId INT NOT NULL, TantargyId INT NOT NULL, TanarSzamit bit, PRIMARY KEY (OsztalyCsoportId, TantargyId));
DECLARE @KapcsolodoCsoportok TABLE(OsztalyCsoportId INT NOT NULL PRIMARY KEY);

-- Ellenőrizzük, hogy az átadott osztalycsoportId + @tantargyId páros előfordul-e sorszámozás összerendelésben
-- ha igen, akkor a hozzá tartozó sorszámozás halmaz alatt lévő összes összerendelésből az összes Osztálycsoport + Tantárgy
-- kombinációt + a tanári lebontást összegyűjtjük és betöltjük a tábla változóba (legfeljebb 1-3 sor)
INSERT INTO @OsztalyTantargy(OsztalyCsoportId, TantargyId, TanarSzamit)
SELECT oh.C_OSZTALYCSOPORTID, oh.C_TANTARGYID, IIF(h.C_KOZOSORASORSZAMOZASELTEROTAN = 'T', 1, 0)
FROM T_ORASORSZAMOZASHALMAZ_OSSZES h
INNER JOIN T_ORASORSZAMOZASHALMAZOSSZEREN_OSSZES oh ON h.ID = oh.C_ORASORSZAMOZASHALMAZID AND oh.TOROLT = 'F'
WHERE h.C_INTEZMENYID = @IntezmenyId
AND h.C_TANEVID = @TanevId
AND h.TOROLT = 'F'
AND EXISTS(
    SELECT * FROM T_ORASORSZAMOZASHALMAZOSSZEREN_OSSZES o1
    WHERE o1.C_INTEZMENYID = @intezmenyId
    AND o1.C_TANEVID = @tanevId
    AND o1.TOROLT = 'F'
    AND o1.C_ORASORSZAMOZASHALMAZID = h.ID
    AND o1.C_TANTARGYID = @tantargyId
    AND o1.C_OSZTALYCSOPORTID = @osztalycsoportId
);

-- Elmentjük, hogy találtunk-e bármilyen összerendelést
IF @@ROWCOUNT > 0 SET @VanOsszerendeles = 1;

-- Ha nem találtunk összerendelést, akkor betöltjük az intézmény szintű beállításokat
IF @VanOsszerendeles = 0
    BEGIN

    SET @TanarSzamit = dbo.fnGetRendszerbeallitasEnumBool(3075, @IntezmenyId, @TanevId);
    SET @OsztalybontasEgybe = dbo.fnGetRendszerbeallitasEnumBool(3078, @IntezmenyId, @TanevId);

    END

-- Ha találtunk összerendelést, akkor az összes kombinációhoz lekérdezzük a tanóra listát
-- a tanári lebontás figyelembe vételével, ez lesz a függvény kimenete
IF @VanOsszerendeles = 1
    INSERT INTO @return(Id, EvesSorszam)
    SELECT 
         t.ID AS Id
        ,t.C_ORAEVESSORSZAMA AS EvesSorszam
    FROM @OsztalyTantargy ot
    INNER JOIN T_TANITASIORA_OSSZES t ON t.C_OSZTALYCSOPORTID = ot.OsztalyCsoportId AND t.C_TANTARGYID = ot.TantargyId
    WHERE t.C_INTEZMENYID = @intezmenyId
    AND t.C_TANEVID = @tanevId 
    AND t.C_TANARID = CASE WHEN ot.TanarSzamit = 1 THEN @tanarId ELSE t.C_TANARID END
    AND t.TOROLT = 'F'
    AND t.C_MEGTARTOTT = 'T'
    AND t.C_SORSZAMOZANDO = 'T'
    AND t.C_ORAKEZDETE <= @datum

ELSE -- Ha nem találtunk összerendeléseket
    IF @OsztalybontasEgybe = 1 -- ha az intézményi szintű beállításokban az osztályok bontott csoportjait egybe kell sorszámozni
        BEGIN
        -- Megkeressük a megadott @osztalycsoportId-hoz tartozó esetleges bontott csoportokat és egy listába töltjük
        INSERT INTO @KapcsolodoCsoportok(OsztalyCsoportId)
        SELECT cs.ID
        FROM T_CSOPORT_OSSZES cs 
        WHERE cs.C_ALINTEZMENYID = @IntezmenyId
        AND cs.C_ALTANEVID = @TanevId
        AND cs.TOROLT = 'F'
        AND (cs.C_OSZTALYBONTASID = @osztalycsoportId OR cs.ID = @osztalycsoportId)
        UNION -- az @osztalycsoportId-t mindenképp felvesszük a listára
        SELECT @osztalycsoportId AS ID;
        -- Lekérdezzük a kimenetre a csoport listához és a tantárgyhoz tartozó tanítási órákat, a tanári lebontás figyelembe vételével
        INSERT INTO @return(Id, EvesSorszam)
        SELECT 
             t.ID AS Id
            ,t.C_ORAEVESSORSZAMA AS EvesSorszam
        FROM T_TANITASIORA_OSSZES t
        WHERE t.C_INTEZMENYID = @intezmenyId
        AND t.C_TANEVID = @tanevId
        AND EXISTS(SELECT * FROM @KapcsolodoCsoportok kcs WHERE kcs.OsztalyCsoportId = t.C_OSZTALYCSOPORTID)
        AND t.C_TANTARGYID = @tantargyId
        AND t.C_TANARID = CASE WHEN @TanarSzamit = 1 THEN @tanarId ELSE t.C_TANARID END
        AND t.TOROLT = 'F'
        AND t.C_MEGTARTOTT = 'T'
        AND t.C_SORSZAMOZANDO = 'T'
        AND t.C_ORAKEZDETE <= @datum

        END

    ELSE -- Ha a bontott csoportok sorszámozása külön történik, akkor a megadott paraméterek alapján a kiementre küldjük a sorokat
        INSERT INTO @return(Id, EvesSorszam)
        SELECT 
             t.ID AS Id
            ,t.C_ORAEVESSORSZAMA AS EvesSorszam
        FROM T_TANITASIORA_OSSZES t
        WHERE t.C_INTEZMENYID = @intezmenyId
        AND t.C_TANEVID = @tanevId
        AND t.C_OSZTALYCSOPORTID = @osztalycsoportId
        AND t.C_TANTARGYID = @tantargyId
        AND t.C_TANARID = CASE WHEN @TanarSzamit = 1 THEN @tanarId ELSE t.C_TANARID END
        AND t.TOROLT = 'F'
        AND t.C_MEGTARTOTT = 'T'
        AND t.C_SORSZAMOZANDO = 'T'
        AND t.C_ORAKEZDETE <= @datum

RETURN;

END
GO